translate.storage.symbian

Package translate :: Package storage :: Module symbian |
[hide private]
[frames] | no frames]

# Module symbian

source code

Classes | [hide private]
| ParseState

Functions | [hide private]
identity(x) | source code
read_while(ps, f, test) | source code
eat_whitespace(ps) | source code
skip_no_translate(ps) | source code
read_charset(lines) | source code

Variables | [hide private]
| charset_re = `re.compile(r'CHARACTER_SET `+``(?P<``charset``>`.`*``)`')`
| header_item_or_end_re = `re.compile(r'`(``(``(?P<``key``>``[^` `]``+``)``(?P<``space``...``
| header_item_re = `re.compile(r'`(?P<``key``>``[^` `]``+``)``(?P<``space``>` `*`: `*``)``(?``...``
| string_entry_re = `re.compile(r'`(?P<``start``>`rls_string `+``)``(?P<``id``>``[``...``
| __package__ = ``'``translate.storage``'``

Imports: re

Variables Details | [hide private]

  ### header_item_or_end_re Value:
      re.compile(r'(((?P<key>[^ ]+)(?P<space> *: *)(?P<value>.*))|(?P<end_co
      mment>\*/))')

  ### header_item_re Value:
      re.compile(r'(?P<key>[^ ]+)(?P<space> *: *)(?P<value>.*)')

  ### string_entry_re Value:
      re.compile(r'(?P<start>rls_string +)(?P<id>[^ ]+)(?P<space> +)(?P<str>
      .*)')